==> sqlitestudio-3.0.7.tar.gz: Plugins/CsvImport/CsvImport_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>CsvImport</name>
    <message>
        <location filename="csvimport.cpp" line="30"/>
        <source>Cannot read file %1</source>
        <translation>Невозможно прочитать файл %1</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="62"/>
        <source>Could not find any data in the file %1.</source>
        <translation>Невозможно найти данные в файле %1.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="167"/>
        <source>Enter the custom separator character.</source>
        <translation>Введите произвольный символ разделителя.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="181"/>
        <source>Enter the value that will be interpreted as a NULL.</source>
        <translation>Введите значение, которое будет интерпретировано как NULL.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="194"/>
        <source>CSV files (*.csv);;Text files (*.txt);;All files (*)</source>
        <translation>Файлы CSV (*.csv);;Текстовые файлы (*.txt);;Все файлы (*)</translation>
    </message>
</context>
<context>
    <name>csvImportOptions</name>
    <message>
        <location filename="CsvImportOptions.ui" line="24"/>
        <source>, (comma)</source>
        <translation>, (запятая)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="29"/>
        <source>; (semicolon)</source>
        <translation>; (точка с запятой)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="34"/>
        <source>\t (tab)</source>
        <translation>\t (табуляция)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="39"/>
        <source>  (whitespace)</source>
        <translation>  (пробел)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="44"/>
        <source>Custom:</source>
        <translation>Произвольный:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="52"/>
        <source>&lt;p&gt;Enable this if the first data line in your CSV file represents column names. You don&apos;t want column names to be imported into the table as a regular data.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Активируйте эту опцию, если в первой строке файла CSV содержатся имена столбцов. Имена столбцов не нужно импортировать как обычные данные.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="55"/>
        <source>First line represents CSV column names</source>
        <translation>Имена столбцов в первой строке</translation>
    </message>
    <message>
        <source>Skip first row of data</source>
        <translation type="obsolete">Пропустить первую строку данных</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="65"/>
        <source>Field separator:</source>
        <translation>Разделитель поля:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="85"/>
        <source>NULL values:</source>
        <translation>Значения NULL:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="95"/>
        <source>If your CSV data contains null values, define how are they represented in the CSV.</source>
        <translation>Если данные в CSV содержат значения NULL, укажите, как они представлены в файле CSV</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/CsvImport/CsvImport_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>CsvImport</name>
    <message>
        <location filename="csvimport.cpp" line="30"/>
        <source>Cannot read file %1</source>
        <translation>Невозможно прочитать файл %1</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="62"/>
        <source>Could not find any data in the file %1.</source>
        <translation>Невозможно найти данные в файле %1.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="163"/>
        <source>Enter the custom separator character.</source>
        <translation>Введите произвольный символ разделителя.</translation>
    </message>
    <message>
        <source>Enter the value that will be interpreted as a NULL.</source>
        <translation type="obsolete">Введите значение, которое будет интерпретировано как NULL.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="186"/>
        <source>CSV files (*.csv);;Text files (*.txt);;All files (*)</source>
        <translation>Файлы CSV (*.csv);;Текстовые файлы (*.txt);;Все файлы (*)</translation>
    </message>
</context>
<context>
    <name>csvImportOptions</name>
    <message>
        <location filename="CsvImportOptions.ui" line="24"/>
        <source>, (comma)</source>
        <translation>, (запятая)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="29"/>
        <source>; (semicolon)</source>
        <translation>; (точка с запятой)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="34"/>
        <source>\t (tab)</source>
        <translation>\t (табуляция)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="39"/>
        <source>  (whitespace)</source>
        <translation>  (пробел)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="44"/>
        <source>Custom:</source>
        <translation>Произвольный:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="52"/>
        <source>&lt;p&gt;Enable this if the first data line in your CSV file represents column names. You don&apos;t want column names to be imported into the table as a regular data.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Активируйте эту опцию, если в первой строке файла CSV содержатся имена столбцов. Имена столбцов не нужно импортировать как обычные данные.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="55"/>
        <source>First line represents CSV column names</source>
        <translation>Имена столбцов в первой строке</translation>
    </message>
    <message>
        <source>Skip first row of data</source>
        <translation type="obsolete">Пропустить первую строку данных</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="65"/>
        <source>Field separator:</source>
        <translation>Разделитель поля:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="85"/>
        <source>If enabled, then text value provided on the right will be interpreted as NULL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="88"/>
        <source>NULL values:</source>
        <translation>Значения NULL:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="98"/>
        <source>If your CSV data contains null values, define how are they represented in the CSV.</source>
        <translation>Если данные в CSV содержат значения NULL, укажите, как они представлены в файле CSV</translation>
    </message>
</context>
</TS>
